@@ -18,4 +18,13 @@ for HASH in sha1 sha256 sha384 sha512; do
     cmp digest1 digest2
 done
 
-rm testdata digest1 digest2
+rm digest1 digest2
+
+# test sign
+openssl genpkey -provider tpm2 -algorithm RSA -pkeyopt bits:2048 -out myrsakey.pem
+
+openssl dgst -provider tpm2 -provider base \
+  -sha256 -sigopt rsa_padding_mode:pss -sigopt rsa_pss_saltlen:-1 -sign myrsakey.pem \
+  -out testdata.sig testdata
+
+rm testdata myrsakey.pem testdata.sig
